@@ -20,14 +20,18 @@ class ReferenceManager(persistent.Persistent,
     def __init__(self):
         self.reference_count = BTrees.OIBTree.OIBTree()
 
-    def register_reference(self, target):
+    def register_reference(self, target, count=1):
         """Register a new reference to the given target."""
+        if count == 0:
+            return
         current = self.reference_count.get(target, 0)
-        self.reference_count[target] = current + 1
+        self.reference_count[target] = current + count
 
-    def unregister_reference(self, target):
+    def unregister_reference(self, target, count=1):
         """Register that a reference to the given target was removed."""
-        new = self.reference_count[target] - 1
+        if count == 0:
+            return
+        new = self.reference_count[target] - count
         if new == 0:
             del self.reference_count[target]
         else:
